window.Gleam.initSearch([{"doc":"midas","title":"midas","content":"# Midas\n\n**Why**: Midas exists to speed up developers by eliminating complexity,&lt;br/&gt;\n**How**: ...by extending type guarantees to all stages of development,&lt;br/&gt;\n**What**: ...with a Gleam library to replace use of build and deploy tools like Bash/Make.\n\n[![Package Version](https://img.shields.io/hexpm/v/midas)](https://hex.pm/packages/midas)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/midas/)\n\n```sh\ngleam add midas\n```\n\n## Task definition vs running a task\n\nMidas separates defining tasks from running tasks.\nThe `midas/task` module is for defining tasks, this is normally the module you want to start with.\n\n```gleam\nimport midas/task as t\n\npub fn task() {\n  let request = // ...\n  use response &lt;- t.do(t.fetch(request))\n  use Nil &lt;- t.do(t.log(&quot;Fetched&quot;))\n  t.done(Nil)\n}\n```\n\nRunning tasks is handled by modules specific to the environment the tasks are running in,\nfor example `midas/node` or `midas/browser`. \n\nThis separation has several benefits:\n- Run tasks in different environments\n- Switch out implementations, i.e. choose different HTTP clients\n- No need to use mocks for testing just use a test task runner.\n- Allows middleware, for example to add spans for tracing\n\n```gleam\nimport midas/node\n\npub fn main() {\n  node.run(task())\n}\n```\n\n## A note on SDKs\n\nLibraries can use the task definition to specify calling an API without needing to choose a how the task is run.\ni.e. there should be less cases where the library needs changing to run on JS or erlang.\n\nFor example using the twitter SDK.\n\n```gleam\npub fn run() {\n  use token &lt;- t.do(twitter.authenticate(client_id, redirect_uri, scopes))\n  use response &lt;- t.do(twitter.user_by_username(token, &quot;crowdhailer&quot;))\n  io.debug(response)\n  t.Done(response)\n}\n```\n\nYou can follow this example on [gleamtours.com](todo) where the task runs in the browser.\n\n## A note of effects\n\nThe `midas/task` module defines an `Effect` type which represents all the effects that can be defined for any task.\nGleam doesn&#39;t have an extensible type so the `Effect` type is essentially a single namespace defining all possible effects.\n\nThis is not really a problem because any effect might return an error.\nSo it is always possible to return an error that indicates that the effect is not implemented by a given runner.\n\n\n## A note on errors\n\nUsing `t.fetch(request)` continues with a `Response` type and not a `Result`.\nIn case of an error the task aborts with an error based on the [snag library](https://hex.pm/packages/snag).\nHaving the same error type makes composing tasks much easier.\n\nHowever if you task might recover in the case of an error you should drop down to the effect directly.\nThe return type using the effect directly has an informative error type that has not yet be cast to a `Snag`.\n","url":"index.html"},{"doc":"midas/task","title":"Effect","content":"pub type Effect(a) {\n  Done(a)\n  Abort(Snag)\n  Bundle(\n    module: String,\n    function: String,\n    resume: fn(Result(String, String)) -&gt; Effect(a),\n  )\n  Follow(uri: String, resume: fn(Result(Uri, Nil)) -&gt; Effect(a))\n  Fetch(\n    request: Request(BitArray),\n    resume: fn(Result(Response(BitArray), FetchError)) -&gt;\n      Effect(a),\n  )\n  List(\n    directory: String,\n    resume: fn(Result(List(String), String)) -&gt; Effect(a),\n  )\n  Log(message: String, resume: fn(Result(Nil, Nil)) -&gt; Effect(a))\n  Read(\n    file: String,\n    resume: fn(Result(BitArray, String)) -&gt; Effect(a),\n  )\n  Write(\n    file: String,\n    bytes: BitArray,\n    resume: fn(Result(Nil, String)) -&gt; Effect(a),\n  )\n  Zip(\n    files: List(#(String, BitArray)),\n    resume: fn(Result(BitArray, Nil)) -&gt; Effect(a),\n  )\n}\n\nDone(a)\n\n\nAbort(Snag)\n\n\nBundle(\n  module: String,\n  function: String,\n  resume: fn(Result(String, String)) -&gt; Effect(a),\n)\n\n\nFollow(uri: String, resume: fn(Result(Uri, Nil)) -&gt; Effect(a))\n\n\nFetch(\n  request: Request(BitArray),\n  resume: fn(Result(Response(BitArray), FetchError)) -&gt; Effect(a),\n)\n\n\nList(\n  directory: String,\n  resume: fn(Result(List(String), String)) -&gt; Effect(a),\n)\n\n\nLog(message: String, resume: fn(Result(Nil, Nil)) -&gt; Effect(a))\n\n\nRead(\n  file: String,\n  resume: fn(Result(BitArray, String)) -&gt; Effect(a),\n)\n\n\nWrite(\n  file: String,\n  bytes: BitArray,\n  resume: fn(Result(Nil, String)) -&gt; Effect(a),\n)\n\n\nZip(\n  files: List(#(String, BitArray)),\n  resume: fn(Result(BitArray, Nil)) -&gt; Effect(a),\n)\n\n\nSynonyms:\nmidas/task.Effect\nmidas/task Effect","url":"midas/task.html#Effect"},{"doc":"midas/task","title":"FetchError","content":"pub type FetchError {\n  NetworkError(String)\n  UnableToReadBody\n  NotImplemented\n}\n\nNetworkError(String)\n\n\nUnableToReadBody\n\n\nNotImplemented\n\n\nSynonyms:\nmidas/task.FetchError\nmidas/task FetchError","url":"midas/task.html#FetchError"},{"doc":"midas/task","title":"abort","content":"pub fn abort(value: Snag) -&gt; Effect(a)\n\nSynonyms:\nmidas/task.abort\nmidas/task abort","url":"midas/task.html#abort"},{"doc":"midas/task","title":"bundle","content":"pub fn bundle(m: String, f: String) -&gt; Effect(String)\n\nSynonyms:\nmidas/task.bundle\nmidas/task bundle","url":"midas/task.html#bundle"},{"doc":"midas/task","title":"do","content":"pub fn do(eff: Effect(a), then: fn(a) -&gt; Effect(b)) -&gt; Effect(b)\n\nSynonyms:\nmidas/task.do\nmidas/task do","url":"midas/task.html#do"},{"doc":"midas/task","title":"done","content":"pub fn done(value: a) -&gt; Effect(a)\n\nSynonyms:\nmidas/task.done\nmidas/task done","url":"midas/task.html#done"},{"doc":"midas/task","title":"each","content":"pub fn each(\n  items: List(a),\n  run: fn(a) -&gt; Effect(b),\n) -&gt; Effect(List(b))\n\nSynonyms:\nmidas/task.each\nmidas/task each","url":"midas/task.html#each"},{"doc":"midas/task","title":"fetch","content":"pub fn fetch(\n  request: Request(BitArray),\n) -&gt; Effect(Response(BitArray))\n\nSynonyms:\nmidas/task.fetch\nmidas/task fetch","url":"midas/task.html#fetch"},{"doc":"midas/task","title":"follow","content":"pub fn follow(uri: String) -&gt; Effect(Uri)\n\nSynonyms:\nmidas/task.follow\nmidas/task follow","url":"midas/task.html#follow"},{"doc":"midas/task","title":"list","content":"pub fn list(file: String) -&gt; Effect(List(String))\n\nSynonyms:\nmidas/task.list\nmidas/task list","url":"midas/task.html#list"},{"doc":"midas/task","title":"log","content":"pub fn log(message: String) -&gt; Effect(Nil)\n\nSynonyms:\nmidas/task.log\nmidas/task log","url":"midas/task.html#log"},{"doc":"midas/task","title":"read","content":"pub fn read(file: String) -&gt; Effect(BitArray)\n\nSynonyms:\nmidas/task.read\nmidas/task read","url":"midas/task.html#read"},{"doc":"midas/task","title":"sequential","content":"pub fn sequential(tasks: List(Effect(a))) -&gt; Effect(List(a))\n\nSynonyms:\nmidas/task.sequential\nmidas/task sequential","url":"midas/task.html#sequential"},{"doc":"midas/task","title":"try","content":"pub fn try(\n  result: Result(a, Snag),\n  then: fn(a) -&gt; Effect(b),\n) -&gt; Effect(b)\n\nSynonyms:\nmidas/task.try\nmidas/task try","url":"midas/task.html#try"},{"doc":"midas/task","title":"write","content":"pub fn write(file: String, bytes: BitArray) -&gt; Effect(Nil)\n\nSynonyms:\nmidas/task.write\nmidas/task write","url":"midas/task.html#write"},{"doc":"midas/task","title":"zip","content":"pub fn zip(\n  message: List(#(String, BitArray)),\n) -&gt; Effect(BitArray)\n\nSynonyms:\nmidas/task.zip\nmidas/task zip","url":"midas/task.html#zip"},{"doc":"midas/task","title":"midas/task","content":"","url":"midas/task.html"},{"doc":"midas/sdk/google","title":"App","content":"pub type App {\n  App(client_id: String, redirect_uri: String)\n}\n\nApp(client_id: String, redirect_uri: String)\n\n\nSynonyms:\nmidas/sdk/google.App\nmidas/sdk/google App","url":"midas/sdk/google.html#App"},{"doc":"midas/sdk/google","title":"auth_redirect","content":"pub fn auth_redirect(\n  redirect: Uri,\n) -&gt; Result(#(String, String, String), String)\n\nSynonyms:\nmidas/sdk/google.auth_redirect\nmidas/sdk/google auth_redirect","url":"midas/sdk/google.html#auth_redirect"},{"doc":"midas/sdk/google","title":"authenticate","content":"pub fn authenticate(\n  app: App,\n  scopes: List(String),\n) -&gt; Effect(String)\n\nSynonyms:\nmidas/sdk/google.authenticate\nmidas/sdk/google authenticate","url":"midas/sdk/google.html#authenticate"},{"doc":"midas/sdk/google","title":"userinfo","content":"pub fn userinfo(token: String) -&gt; Effect(String)\n\nSynonyms:\nmidas/sdk/google.userinfo\nmidas/sdk/google userinfo","url":"midas/sdk/google.html#userinfo"},{"doc":"midas/sdk/google","title":"userinfo_request","content":"pub fn userinfo_request(token: String) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/google.userinfo_request\nmidas/sdk/google userinfo_request","url":"midas/sdk/google.html#userinfo_request"},{"doc":"midas/sdk/google","title":"userinfo_response","content":"pub fn userinfo_response(\n  response: Response(BitArray),\n) -&gt; Result(String, Snag)\n\nSynonyms:\nmidas/sdk/google.userinfo_response\nmidas/sdk/google userinfo_response","url":"midas/sdk/google.html#userinfo_response"},{"doc":"midas/sdk/google","title":"midas/sdk/google","content":"","url":"midas/sdk/google.html"},{"doc":"midas/sdk/google/gmail","title":"Message","content":"pub type Message {\n  Message(id: String, thread_id: String)\n}\n\nMessage(id: String, thread_id: String)\n\n\nSynonyms:\nmidas/sdk/google/gmail.Message\nmidas/sdk/google/gmail Message","url":"midas/sdk/google/gmail.html#Message"},{"doc":"midas/sdk/google/gmail","title":"list_messages","content":"pub fn list_messages(\n  token: String,\n  user_id: String,\n) -&gt; Effect(List(Message))\n\nSynonyms:\nmidas/sdk/google/gmail.list_messages\nmidas/sdk/google/gmail list_messages","url":"midas/sdk/google/gmail.html#list_messages"},{"doc":"midas/sdk/google/gmail","title":"list_messages_request","content":"pub fn list_messages_request(\n  token: String,\n  user_id: String,\n) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/google/gmail.list_messages_request\nmidas/sdk/google/gmail list_messages_request","url":"midas/sdk/google/gmail.html#list_messages_request"},{"doc":"midas/sdk/google/gmail","title":"list_messages_response","content":"pub fn list_messages_response(\n  response: Response(BitArray),\n) -&gt; Result(List(Message), Snag)\n\nSynonyms:\nmidas/sdk/google/gmail.list_messages_response\nmidas/sdk/google/gmail list_messages_response","url":"midas/sdk/google/gmail.html#list_messages_response"},{"doc":"midas/sdk/google/gmail","title":"send","content":"pub fn send(\n  token: String,\n  from: String,\n  to: String,\n  message: String,\n) -&gt; Effect(Message)\n\nSynonyms:\nmidas/sdk/google/gmail.send\nmidas/sdk/google/gmail send","url":"midas/sdk/google/gmail.html#send"},{"doc":"midas/sdk/google/gmail","title":"send_request","content":"pub fn send_request(\n  token: String,\n  from: String,\n  to: String,\n  message: String,\n) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/google/gmail.send_request\nmidas/sdk/google/gmail send_request","url":"midas/sdk/google/gmail.html#send_request"},{"doc":"midas/sdk/google/gmail","title":"send_response","content":"pub fn send_response(\n  response: Response(BitArray),\n) -&gt; Result(Message, Snag)\n\nSynonyms:\nmidas/sdk/google/gmail.send_response\nmidas/sdk/google/gmail send_response","url":"midas/sdk/google/gmail.html#send_response"},{"doc":"midas/sdk/google/gmail","title":"midas/sdk/google/gmail","content":"","url":"midas/sdk/google/gmail.html"},{"doc":"midas/sdk/linkedin","title":"App","content":"pub type App {\n  App(\n    client_id: String,\n    client_secret: String,\n    redirect_uri: String,\n  )\n}\n\nApp(\n  client_id: String,\n  client_secret: String,\n  redirect_uri: String,\n)\n\n\nSynonyms:\nmidas/sdk/linkedin.App\nmidas/sdk/linkedin App","url":"midas/sdk/linkedin.html#App"},{"doc":"midas/sdk/linkedin","title":"Author","content":"pub type Author {\n  Person(id: String)\n  Organization(id: String)\n}\n\nPerson(id: String)\n\n\nOrganization(id: String)\n\n\nSynonyms:\nmidas/sdk/linkedin.Author\nmidas/sdk/linkedin Author","url":"midas/sdk/linkedin.html#Author"},{"doc":"midas/sdk/linkedin","title":"Content","content":"pub type Content {\n  Article(\n    description: Option(String),\n    source: String,\n    thumbnail: Option(Image),\n    thumbnail_alt_text: Option(String),\n    title: String,\n  )\n}\n\nArticle(\n  description: Option(String),\n  source: String,\n  thumbnail: Option(Image),\n  thumbnail_alt_text: Option(String),\n  title: String,\n)\n\n\nSynonyms:\nmidas/sdk/linkedin.Content\nmidas/sdk/linkedin Content","url":"midas/sdk/linkedin.html#Content"},{"doc":"midas/sdk/linkedin","title":"Image","content":"pub type Image {\n  Image(id: String)\n}\n\nImage(id: String)\n\n\nSynonyms:\nmidas/sdk/linkedin.Image\nmidas/sdk/linkedin Image","url":"midas/sdk/linkedin.html#Image"},{"doc":"midas/sdk/linkedin","title":"InitializeImageUpload","content":"pub type InitializeImageUpload {\n  InitializeImageUpload(\n    upload_url_expires_at: Int,\n    upload_url: String,\n    image: String,\n  )\n}\n\nInitializeImageUpload(\n  upload_url_expires_at: Int,\n  upload_url: String,\n  image: String,\n)\n\n\nSynonyms:\nmidas/sdk/linkedin.InitializeImageUpload\nmidas/sdk/linkedin InitializeImageUpload","url":"midas/sdk/linkedin.html#InitializeImageUpload"},{"doc":"midas/sdk/linkedin","title":"Share","content":"pub type Share {\n  Share(id: String)\n}\n\nShare(id: String)\n\n\nSynonyms:\nmidas/sdk/linkedin.Share\nmidas/sdk/linkedin Share","url":"midas/sdk/linkedin.html#Share"},{"doc":"midas/sdk/linkedin","title":"Userinfo","content":"pub type Userinfo {\n  Userinfo(sub: String)\n}\n\nUserinfo(sub: String)\n\n\nSynonyms:\nmidas/sdk/linkedin.Userinfo\nmidas/sdk/linkedin Userinfo","url":"midas/sdk/linkedin.html#Userinfo"},{"doc":"midas/sdk/linkedin","title":"Visability","content":"pub type Visability {\n  Connections\n  Public\n  LoggedIn\n  Container\n}\n\nConnections\n\n\nPublic\n\n\nLoggedIn\n\n\nContainer\n\n\nSynonyms:\nmidas/sdk/linkedin.Visability\nmidas/sdk/linkedin Visability","url":"midas/sdk/linkedin.html#Visability"},{"doc":"midas/sdk/linkedin","title":"auth_redirect","content":"pub fn auth_redirect(\n  redirect: Uri,\n) -&gt; Result(#(String, String), String)\n\nSynonyms:\nmidas/sdk/linkedin.auth_redirect\nmidas/sdk/linkedin auth_redirect","url":"midas/sdk/linkedin.html#auth_redirect"},{"doc":"midas/sdk/linkedin","title":"authenticate","content":"pub fn authenticate(\n  app: App,\n  scopes: List(String),\n) -&gt; Effect(String)\n\nSynonyms:\nmidas/sdk/linkedin.authenticate\nmidas/sdk/linkedin authenticate","url":"midas/sdk/linkedin.html#authenticate"},{"doc":"midas/sdk/linkedin","title":"author_to_urn","content":"pub fn author_to_urn(author: Author) -&gt; String\n\nSynonyms:\nmidas/sdk/linkedin.author_to_urn\nmidas/sdk/linkedin author_to_urn","url":"midas/sdk/linkedin.html#author_to_urn"},{"doc":"midas/sdk/linkedin","title":"content_to_json","content":"pub fn content_to_json(content: Content) -&gt; Json\n\nSynonyms:\nmidas/sdk/linkedin.content_to_json\nmidas/sdk/linkedin content_to_json","url":"midas/sdk/linkedin.html#content_to_json"},{"doc":"midas/sdk/linkedin","title":"create_post","content":"pub fn create_post(\n  token: String,\n  user_id: Author,\n  content: Option(Content),\n  commentary: String,\n) -&gt; Effect(String)\n\nSynonyms:\nmidas/sdk/linkedin.create_post\nmidas/sdk/linkedin create_post","url":"midas/sdk/linkedin.html#create_post"},{"doc":"midas/sdk/linkedin","title":"create_post_request","content":"pub fn create_post_request(\n  token: String,\n  author: Author,\n  content: Option(Content),\n  commentary: String,\n) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/linkedin.create_post_request\nmidas/sdk/linkedin create_post_request","url":"midas/sdk/linkedin.html#create_post_request"},{"doc":"midas/sdk/linkedin","title":"create_post_response","content":"pub fn create_post_response(\n  response: Response(BitArray),\n) -&gt; Result(String, Snag)\n\nSynonyms:\nmidas/sdk/linkedin.create_post_response\nmidas/sdk/linkedin create_post_response","url":"midas/sdk/linkedin.html#create_post_response"},{"doc":"midas/sdk/linkedin","title":"get_post","content":"pub fn get_post(\n  token: String,\n  share: Share,\n) -&gt; Effect(Response(BitArray))\n\nSynonyms:\nmidas/sdk/linkedin.get_post\nmidas/sdk/linkedin get_post","url":"midas/sdk/linkedin.html#get_post"},{"doc":"midas/sdk/linkedin","title":"get_post_request","content":"pub fn get_post_request(\n  token: String,\n  share: Share,\n) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/linkedin.get_post_request\nmidas/sdk/linkedin get_post_request","url":"midas/sdk/linkedin.html#get_post_request"},{"doc":"midas/sdk/linkedin","title":"get_posts","content":"pub fn get_posts(\n  token: String,\n  author: Author,\n) -&gt; Effect(Response(BitArray))\n\nSynonyms:\nmidas/sdk/linkedin.get_posts\nmidas/sdk/linkedin get_posts","url":"midas/sdk/linkedin.html#get_posts"},{"doc":"midas/sdk/linkedin","title":"get_posts_request","content":"pub fn get_posts_request(\n  token: String,\n  author: Author,\n) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/linkedin.get_posts_request\nmidas/sdk/linkedin get_posts_request","url":"midas/sdk/linkedin.html#get_posts_request"},{"doc":"midas/sdk/linkedin","title":"image_to_urn","content":"pub fn image_to_urn(image: Image) -&gt; String\n\nSynonyms:\nmidas/sdk/linkedin.image_to_urn\nmidas/sdk/linkedin image_to_urn","url":"midas/sdk/linkedin.html#image_to_urn"},{"doc":"midas/sdk/linkedin","title":"initialize_image_upload","content":"pub fn initialize_image_upload(\n  token: String,\n  owner: Author,\n) -&gt; Effect(InitializeImageUpload)\n\nSynonyms:\nmidas/sdk/linkedin.initialize_image_upload\nmidas/sdk/linkedin initialize_image_upload","url":"midas/sdk/linkedin.html#initialize_image_upload"},{"doc":"midas/sdk/linkedin","title":"initialize_image_upload_decoder","content":"pub fn initialize_image_upload_decoder(\n  raw: Dynamic,\n) -&gt; Result(InitializeImageUpload, List(DecodeError))\n\nSynonyms:\nmidas/sdk/linkedin.initialize_image_upload_decoder\nmidas/sdk/linkedin initialize_image_upload_decoder","url":"midas/sdk/linkedin.html#initialize_image_upload_decoder"},{"doc":"midas/sdk/linkedin","title":"initialize_image_upload_request","content":"pub fn initialize_image_upload_request(\n  token: String,\n  owner: Author,\n) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/linkedin.initialize_image_upload_request\nmidas/sdk/linkedin initialize_image_upload_request","url":"midas/sdk/linkedin.html#initialize_image_upload_request"},{"doc":"midas/sdk/linkedin","title":"initialize_image_upload_response","content":"pub fn initialize_image_upload_response(\n  response: Response(BitArray),\n) -&gt; Result(InitializeImageUpload, Snag)\n\nSynonyms:\nmidas/sdk/linkedin.initialize_image_upload_response\nmidas/sdk/linkedin initialize_image_upload_response","url":"midas/sdk/linkedin.html#initialize_image_upload_response"},{"doc":"midas/sdk/linkedin","title":"token_request","content":"pub fn token_request(\n  client_id: String,\n  redirect_uri: String,\n  client_secret: String,\n  code: String,\n) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/linkedin.token_request\nmidas/sdk/linkedin token_request","url":"midas/sdk/linkedin.html#token_request"},{"doc":"midas/sdk/linkedin","title":"token_response","content":"pub fn token_response(\n  response: Response(BitArray),\n) -&gt; Result(String, a)\n\nSynonyms:\nmidas/sdk/linkedin.token_response\nmidas/sdk/linkedin token_response","url":"midas/sdk/linkedin.html#token_response"},{"doc":"midas/sdk/linkedin","title":"upload_image","content":"pub fn upload_image(\n  token: String,\n  owner: Author,\n  bits: BitArray,\n) -&gt; Effect(Image)\n\nSynonyms:\nmidas/sdk/linkedin.upload_image\nmidas/sdk/linkedin upload_image","url":"midas/sdk/linkedin.html#upload_image"},{"doc":"midas/sdk/linkedin","title":"userinfo","content":"pub fn userinfo(token: String) -&gt; Effect(Userinfo)\n\nSynonyms:\nmidas/sdk/linkedin.userinfo\nmidas/sdk/linkedin userinfo","url":"midas/sdk/linkedin.html#userinfo"},{"doc":"midas/sdk/linkedin","title":"userinfo_request","content":"pub fn userinfo_request(token: String) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/linkedin.userinfo_request\nmidas/sdk/linkedin userinfo_request","url":"midas/sdk/linkedin.html#userinfo_request"},{"doc":"midas/sdk/linkedin","title":"userinfo_response","content":"pub fn userinfo_response(\n  response: Response(BitArray),\n) -&gt; Result(Userinfo, Snag)\n\nSynonyms:\nmidas/sdk/linkedin.userinfo_response\nmidas/sdk/linkedin userinfo_response","url":"midas/sdk/linkedin.html#userinfo_response"},{"doc":"midas/sdk/linkedin","title":"visability_to_string","content":"pub fn visability_to_string(visability: Visability) -&gt; String\n\nSynonyms:\nmidas/sdk/linkedin.visability_to_string\nmidas/sdk/linkedin visability_to_string","url":"midas/sdk/linkedin.html#visability_to_string"},{"doc":"midas/sdk/linkedin","title":"midas/sdk/linkedin","content":"","url":"midas/sdk/linkedin.html"},{"doc":"midas/sdk/netlify","title":"App","content":"pub type App {\n  App(client_id: String, redirect_uri: String)\n}\n\nApp(client_id: String, redirect_uri: String)\n\n\nSynonyms:\nmidas/sdk/netlify.App\nmidas/sdk/netlify App","url":"midas/sdk/netlify.html#App"},{"doc":"midas/sdk/netlify","title":"Site","content":"pub type Site {\n  Site(id: String, state: String, name: String, url: String)\n}\n\nSite(id: String, state: String, name: String, url: String)\n\n\nSynonyms:\nmidas/sdk/netlify.Site\nmidas/sdk/netlify Site","url":"midas/sdk/netlify.html#Site"},{"doc":"midas/sdk/netlify","title":"auth_redirect","content":"pub fn auth_redirect(\n  redirect: Uri,\n) -&gt; Result(#(String, String, String), String)\n\nSynonyms:\nmidas/sdk/netlify.auth_redirect\nmidas/sdk/netlify auth_redirect","url":"midas/sdk/netlify.html#auth_redirect"},{"doc":"midas/sdk/netlify","title":"authenticate","content":"pub fn authenticate(app: App) -&gt; Effect(String)\n\nSynonyms:\nmidas/sdk/netlify.authenticate\nmidas/sdk/netlify authenticate","url":"midas/sdk/netlify.html#authenticate"},{"doc":"midas/sdk/netlify","title":"deploy_site","content":"pub fn deploy_site(\n  token: String,\n  site_id: String,\n  files: List(#(String, BitArray)),\n) -&gt; Effect(String)\n\nSynonyms:\nmidas/sdk/netlify.deploy_site\nmidas/sdk/netlify deploy_site","url":"midas/sdk/netlify.html#deploy_site"},{"doc":"midas/sdk/netlify","title":"list_sites","content":"pub fn list_sites(token: String) -&gt; Effect(List(Site))\n\nSynonyms:\nmidas/sdk/netlify.list_sites\nmidas/sdk/netlify list_sites","url":"midas/sdk/netlify.html#list_sites"},{"doc":"midas/sdk/netlify","title":"list_sites_request","content":"pub fn list_sites_request(token: String) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/netlify.list_sites_request\nmidas/sdk/netlify list_sites_request","url":"midas/sdk/netlify.html#list_sites_request"},{"doc":"midas/sdk/netlify","title":"list_sites_response","content":"pub fn list_sites_response(\n  response: Response(BitArray),\n) -&gt; Result(List(Site), Snag)\n\nSynonyms:\nmidas/sdk/netlify.list_sites_response\nmidas/sdk/netlify list_sites_response","url":"midas/sdk/netlify.html#list_sites_response"},{"doc":"midas/sdk/netlify","title":"midas/sdk/netlify","content":"","url":"midas/sdk/netlify.html"},{"doc":"midas/sdk/twitter","title":"auth_redirect","content":"pub fn auth_redirect(\n  redirect: Uri,\n) -&gt; Result(#(String, String), String)\n\nSynonyms:\nmidas/sdk/twitter.auth_redirect\nmidas/sdk/twitter auth_redirect","url":"midas/sdk/twitter.html#auth_redirect"},{"doc":"midas/sdk/twitter","title":"auth_url","content":"pub fn auth_url(\n  client_id: String,\n  redirect_uri: String,\n  scopes: List(String),\n  state: String,\n  challenge: String,\n) -&gt; String\n\nSynonyms:\nmidas/sdk/twitter.auth_url\nmidas/sdk/twitter auth_url","url":"midas/sdk/twitter.html#auth_url"},{"doc":"midas/sdk/twitter","title":"authenticate","content":"pub fn authenticate(\n  client_id: String,\n  redirect_uri: String,\n  scopes: List(String),\n) -&gt; Effect(String)\n\nSynonyms:\nmidas/sdk/twitter.authenticate\nmidas/sdk/twitter authenticate","url":"midas/sdk/twitter.html#authenticate"},{"doc":"midas/sdk/twitter","title":"create_tweet","content":"pub fn create_tweet(\n  token: String,\n  text: String,\n) -&gt; Effect(Response(BitArray))\n\nSynonyms:\nmidas/sdk/twitter.create_tweet\nmidas/sdk/twitter create_tweet","url":"midas/sdk/twitter.html#create_tweet"},{"doc":"midas/sdk/twitter","title":"create_tweet_request","content":"pub fn create_tweet_request(\n  token: String,\n  text: String,\n) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/twitter.create_tweet_request\nmidas/sdk/twitter create_tweet_request","url":"midas/sdk/twitter.html#create_tweet_request"},{"doc":"midas/sdk/twitter","title":"token_request","content":"pub fn token_request(\n  client_id: String,\n  redirect_uri: String,\n  code_verifier: String,\n  code: String,\n) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/twitter.token_request\nmidas/sdk/twitter token_request","url":"midas/sdk/twitter.html#token_request"},{"doc":"midas/sdk/twitter","title":"token_response","content":"pub fn token_response(\n  response: Response(BitArray),\n) -&gt; Result(String, a)\n\nSynonyms:\nmidas/sdk/twitter.token_response\nmidas/sdk/twitter token_response","url":"midas/sdk/twitter.html#token_response"},{"doc":"midas/sdk/twitter","title":"user_by_username","content":"pub fn user_by_username(\n  token: String,\n  username: String,\n) -&gt; Effect(Response(BitArray))\n\nSynonyms:\nmidas/sdk/twitter.user_by_username\nmidas/sdk/twitter user_by_username","url":"midas/sdk/twitter.html#user_by_username"},{"doc":"midas/sdk/twitter","title":"user_by_username_request","content":"pub fn user_by_username_request(\n  token: String,\n  username: String,\n) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/twitter.user_by_username_request\nmidas/sdk/twitter user_by_username_request","url":"midas/sdk/twitter.html#user_by_username_request"},{"doc":"midas/sdk/twitter","title":"user_timeline","content":"pub fn user_timeline(\n  token: String,\n  user_id: String,\n) -&gt; Effect(Dynamic)\n\nSynonyms:\nmidas/sdk/twitter.user_timeline\nmidas/sdk/twitter user_timeline","url":"midas/sdk/twitter.html#user_timeline"},{"doc":"midas/sdk/twitter","title":"user_timeline_request","content":"pub fn user_timeline_request(\n  token: String,\n  user_id: String,\n) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/twitter.user_timeline_request\nmidas/sdk/twitter user_timeline_request","url":"midas/sdk/twitter.html#user_timeline_request"},{"doc":"midas/sdk/twitter","title":"user_timeline_response","content":"pub fn user_timeline_response(\n  response: Response(BitArray),\n) -&gt; Result(Dynamic, a)\n\nSynonyms:\nmidas/sdk/twitter.user_timeline_response\nmidas/sdk/twitter user_timeline_response","url":"midas/sdk/twitter.html#user_timeline_response"},{"doc":"midas/sdk/twitter","title":"midas/sdk/twitter","content":"","url":"midas/sdk/twitter.html"},{"doc":"midas/sdk/vimeo","title":"App","content":"pub type App {\n  App(client_id: String, redirect_uri: String)\n}\n\nApp(client_id: String, redirect_uri: String)\n\n\nSynonyms:\nmidas/sdk/vimeo.App\nmidas/sdk/vimeo App","url":"midas/sdk/vimeo.html#App"},{"doc":"midas/sdk/vimeo","title":"Video","content":"pub type Video {\n  Video(\n    name: String,\n    link: String,\n    duration: Int,\n    created_time: String,\n    plays: Int,\n    has_audio: Bool,\n  )\n}\n\nVideo(\n  name: String,\n  link: String,\n  duration: Int,\n  created_time: String,\n  plays: Int,\n  has_audio: Bool,\n)\n\n\nSynonyms:\nmidas/sdk/vimeo.Video\nmidas/sdk/vimeo Video","url":"midas/sdk/vimeo.html#Video"},{"doc":"midas/sdk/vimeo","title":"auth_redirect","content":"pub fn auth_redirect(\n  redirect: Uri,\n) -&gt; Result(#(String, String, String), String)\n\nSynonyms:\nmidas/sdk/vimeo.auth_redirect\nmidas/sdk/vimeo auth_redirect","url":"midas/sdk/vimeo.html#auth_redirect"},{"doc":"midas/sdk/vimeo","title":"authenticate","content":"pub fn authenticate(\n  app: App,\n  scopes: List(String),\n) -&gt; Effect(String)\n\nSynonyms:\nmidas/sdk/vimeo.authenticate\nmidas/sdk/vimeo authenticate","url":"midas/sdk/vimeo.html#authenticate"},{"doc":"midas/sdk/vimeo","title":"my_videos","content":"pub fn my_videos(token: String) -&gt; Effect(List(Video))\n\nSynonyms:\nmidas/sdk/vimeo.my_videos\nmidas/sdk/vimeo my_videos","url":"midas/sdk/vimeo.html#my_videos"},{"doc":"midas/sdk/vimeo","title":"my_videos_request","content":"pub fn my_videos_request(token: String) -&gt; Request(BitArray)\n\nSynonyms:\nmidas/sdk/vimeo.my_videos_request\nmidas/sdk/vimeo my_videos_request","url":"midas/sdk/vimeo.html#my_videos_request"},{"doc":"midas/sdk/vimeo","title":"my_videos_response","content":"pub fn my_videos_response(\n  response: Response(BitArray),\n) -&gt; Result(List(Video), Snag)\n\nSynonyms:\nmidas/sdk/vimeo.my_videos_response\nmidas/sdk/vimeo my_videos_response","url":"midas/sdk/vimeo.html#my_videos_response"},{"doc":"midas/sdk/vimeo","title":"video_decoder","content":"pub fn video_decoder(\n  data: Dynamic,\n) -&gt; Result(Video, List(DecodeError))\n\nSynonyms:\nmidas/sdk/vimeo.video_decoder\nmidas/sdk/vimeo video_decoder","url":"midas/sdk/vimeo.html#video_decoder"},{"doc":"midas/sdk/vimeo","title":"midas/sdk/vimeo","content":"","url":"midas/sdk/vimeo.html"}]);